@@ -25,7 +25,7 @@ ROOT_DIR = os.path.abspath("../")
 
 # Import Mask RCNN
 sys.path.append(ROOT_DIR)  # To find local version of the library
-from aidoop.mask_rcnn import utils
+from pyaidoop.mask_rcnn import utils
 
 
 ############################################################
